﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using TreeComboBoxDemo.Model;
using System.ComponentModel;

namespace TreeComboBoxDemo.ViewModel
{

    class VM : INotifyPropertyChanged
    {
        #region INotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;
        protected void RaisePropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null) this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion

        #region 数据源
        private ObservableCollection<TreeItemModel<M_Step>> _TreeComboxItemsSource = default(ObservableCollection<TreeItemModel<M_Step>>);
        public ObservableCollection<TreeItemModel<M_Step>> TreeComboxItemsSource
        {
            get { return _TreeComboxItemsSource; }
            set
            {
                if (_TreeComboxItemsSource != value)
                {
                    _TreeComboxItemsSource = value;
                    this.RaisePropertyChanged("TreeComboxItemsSource");
                }
            }
        }
        #endregion

        #region 选中项
        private TreeItemModel<M_Step> _SelectedItem = default(TreeItemModel<M_Step>);
        public TreeItemModel<M_Step> SelectedItem
        {
            get { return _SelectedItem; }
            set
            {
                if (_SelectedItem != value)
                {
                    _SelectedItem = value;
                    this.RaisePropertyChanged("SelectedItem");
                }
            }
        }
        #endregion

        #region 命令执行结果
        private string _CommandResult = default(string);
        public string CommandResult
        {
            get { return _CommandResult; }
            set
            {
                if (_CommandResult != value)
                {
                    _CommandResult = value;
                    this.RaisePropertyChanged("CommandResult");
                }
            }
        }
        #endregion

        public RelayCommand CMD_TreeViewItemClick { get; set; }

        public VM()
        {
            InitialTreeComboxItemsSource();
            this.SelectedItem = TreeComboxItemsSource.First();
            CMD_TreeViewItemClick = new RelayCommand((arg) =>
            {
                TreeItemModel<M_Step> clickItem = arg as TreeItemModel<M_Step>;
                CommandResult = "ClickTheItem:" + (clickItem ?? new TreeItemModel<M_Step>() { Data = new M_Step { StepName = "NaN" } }).Data.StepName;
            });
        }

        #region 初始化下拉框数据源

        private void InitialTreeComboxItemsSource()
        {

            this.TreeComboxItemsSource = new ObservableCollection<TreeItemModel<M_Step>>();
            TreeItemModel<M_Step> stepGoing = new TreeItemModel<M_Step>();
            stepGoing.Childeren = new ObservableCollection<TreeItemModel<M_Step>>();
            stepGoing.Data = new M_Step()
            {
                StepID = 253,
                StepName = "进行中"
            };
            stepGoing.Childeren.Add(new TreeItemModel<M_Step>
            {
                Data = new M_Step
                {
                    StepID = 1,
                    StepName = "异常报警"
                }
            });
            stepGoing.Childeren.Add(new TreeItemModel<M_Step>
            {
                Data = new M_Step
                {
                    StepID = 2,
                    StepName = "开始对应"
                }
            });
            stepGoing.Childeren.Add(new TreeItemModel<M_Step>
            {
                Data = new M_Step
                {
                    StepID = 3,
                    StepName = "对应完成未记录"
                }
            });
            stepGoing.Childeren.Add(new TreeItemModel<M_Step>
            {
                Data = new M_Step
                {
                    StepID = 99,
                    StepName = "紧急异常报警"
                }
            });
            this.TreeComboxItemsSource.Add(stepGoing);


            TreeItemModel<M_Step> stepComplete = new TreeItemModel<M_Step>();
            stepComplete.Childeren = new ObservableCollection<TreeItemModel<M_Step>>();
            stepComplete.Data = new M_Step()
            {
                StepID = 254,
                StepName = "已结束"
            };
            stepComplete.Childeren.Add(new TreeItemModel<M_Step>
            {
                Data = new M_Step
                {
                    StepID = 4,
                    StepName = "完成"
                }
            });
            stepComplete.Childeren.Add(new TreeItemModel<M_Step>
            {
                Data = new M_Step
                {
                    StepID = 9,
                    StepName = "取消"
                }
            });
            this.TreeComboxItemsSource.Add(stepComplete);
        }
        #endregion
    }
}
